@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.17 2011/10/01 18:06:44 imilh Exp $ */
+/* $Id: main.c,v 1.20 2011/10/23 13:47:03 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010, 2011 The NetBSD Foundation, Inc.
@@ -50,13 +50,13 @@ main(int argc, char *argv[])
 {
 	uint8_t		updb_all;
 	uint8_t		do_inst = DO_INST; /* by default, do install packages */
-	int 		ch;
+	int 		ch, rc = EXIT_SUCCESS;
 	struct stat	sb;
 	const char	*chrootpath = NULL;
 
 	setprogname(argv[0]);
 
-	if (argc < 2)
+	if (argc < 2 || *argv[1] == 'h')
 		usage();
 
 	while ((ch = getopt(argc, argv, "dhyfFPvVl:nc:t:")) != -1) {
@@ -143,7 +143,7 @@ main(int argc, char *argv[])
 	updb_all = upgrade_database();
 
 	/* update local db if pkgdb mtime has changed */
-	update_db(LOCAL_SUMMARY, NULL);
+	(void)update_db(LOCAL_SUMMARY, NULL);
 
 	/* split PKG_REPOS env variable and record them */
 	split_repos();
@@ -153,7 +153,7 @@ main(int argc, char *argv[])
 	 * or if empty database
 	 */
 	if (updb_all)
-		update_db(REMOTE_SUMMARY, NULL);
+		(void)update_db(REMOTE_SUMMARY, NULL);
 
 	/* find command index */
 	ch = find_cmd(argv[0]);
@@ -170,20 +170,21 @@ main(int argc, char *argv[])
 
 	switch (ch) {
 	case PKG_UPDT_CMD: /* update packages db */
-		update_db(REMOTE_SUMMARY, NULL);
+		if (update_db(REMOTE_SUMMARY, NULL) == EXIT_FAILURE)
+			errx(EXIT_FAILURE, MSG_DONT_HAVE_RIGHTS);
 		break;
 	case PKG_SHDDP_CMD: /* show direct depends */
 		missing_param(argc, 2, MSG_MISSING_PKGNAME);
-		show_direct_depends(argv[1]);
+		rc = show_direct_depends(argv[1]);
 		break;
 	case PKG_SHFDP_CMD: /* show full dependency tree */
 		missing_param(argc, 2, MSG_MISSING_PKGNAME);
-		show_full_dep_tree(argv[1],
+		rc = show_full_dep_tree(argv[1],
 			DIRECT_DEPS, MSG_FULLDEPTREE);
 		break;
 	case PKG_SHRDP_CMD: /* show full reverse dependency tree */
 		missing_param(argc, 2, MSG_MISSING_PKGNAME);
-		show_full_dep_tree(argv[1],
+		rc = show_full_dep_tree(argv[1],
 			LOCAL_REVERSE_DEPS,
 			MSG_REVDEPTREE);
 		break;
@@ -261,7 +262,7 @@ main(int argc, char *argv[])
 	XFREE(env_repos);
 	XFREE(pkg_repos);
 
-	return EXIT_SUCCESS;
+	return rc;
 }
 
 static void
